pub struct Message {
pub role: Role,
pub content: Option<Value>,
pub tool_calls: Option<Vec<ToolCall>>,
pub tool_call_id: Option<String>,
pub name: Option<String>,
pub reasoning_content: Option<String>,
pub extra: Map<String, Value>,
}Fields
role: Rolecontent: Option<Value>tool_calls: Option<Vec<ToolCall>>tool_call_id: Option<String>name: Option<String>reasoning_content: Option<String>extra: Map<String, Value>Implementations
Sourceimpl Message
impl Message
Sourcepub fn user(content: impl Into<String>) -> Message
pub fn user(content: impl Into<String>) -> Message
Build a Message with role User and the given text content.
Sourcepub fn assistant(content: impl Into<String>) -> Message
pub fn assistant(content: impl Into<String>) -> Message
Build a Message with role Assistant and the given text content.
Sourcepub fn system(content: impl Into<String>) -> Message
pub fn system(content: impl Into<String>) -> Message
Build a Message with role System and the given text content.
Sourcepub fn tool(
tool_call_id: impl Into<String>,
name: impl Into<String>,
content: impl Into<String>,
) -> Message
pub fn tool( tool_call_id: impl Into<String>, name: impl Into<String>, content: impl Into<String>, ) -> Message
Build a Message with role Tool, setting tool_call_id and name.
Sourcepub fn content_str(&self) -> Option<&str>
pub fn content_str(&self) -> Option<&str>
Return the text view of content when it is a non-empty JSON string.
Returns None for null, empty strings, and non-string variants
(e.g. multimodal arrays).