Msg

Enum Msg 

pub enum Msg {
Show 46 variants Send(SendMsg), Stream(StreamMsg), ReplyToAsk(ReplyToAsk), ListActiveConversations(ListActiveConversationsMsg), Kill(KillMsg), Compact(CompactMsg), ListConversations(ListConversationsMsg), ListProviders(ListProvidersMsg), SetProvider(SetProviderMsg), DeleteProvider(DeleteProviderMsg), SetActiveModel(SetActiveModelMsg), ListProviderPresets(ListProviderPresetsMsg), ListMcps(ListMcpsMsg), UpsertMcp(UpsertMcpMsg), DeleteMcp(DeleteMcpMsg), ListAgents(ListAgentsMsg), GetAgent(GetAgentMsg), CreateAgent(CreateAgentMsg), UpdateAgent(UpdateAgentMsg), DeleteAgent(DeleteAgentMsg), RenameAgent(RenameAgentMsg), InstallPlugin(InstallPluginMsg), UninstallPlugin(UninstallPluginMsg), ListPlugins(ListPluginsMsg), ListSkills(ListSkillsMsg), ListModels(ListModelsMsg), SearchPlugins(SearchPluginsMsg), GetConversationHistory(GetConversationHistoryMsg), DeleteConversation(DeleteConversationMsg), StartService(StartServiceMsg), StopService(StopServiceMsg), ServiceLogs(ServiceLogsMsg), CreateCron(CreateCronMsg), DeleteCron(DeleteCronMsg), ListCrons(ListCronsMsg), Ping(Ping), GetConfig(GetConfig), Reload(ReloadMsg), GetStats(GetStats), SubscribeEvents(SubscribeEvents), SubscribeEvent(SubscribeEventMsg), UnsubscribeEvent(UnsubscribeEventMsg), ListSubscriptions(ListSubscriptionsMsg), PublishEvent(PublishEventMsg), SteerSession(SteerSessionMsg), Extension(Vec<u8>),
}

Variants



Send(SendMsg)

Execution



Stream(StreamMsg)



ReplyToAsk(ReplyToAsk)



ListActiveConversations(ListActiveConversationsMsg)

Conversation management



Kill(KillMsg)



Compact(CompactMsg)



ListConversations(ListConversationsMsg)



ListProviders(ListProvidersMsg)

Provider management



SetProvider(SetProviderMsg)



DeleteProvider(DeleteProviderMsg)



SetActiveModel(SetActiveModelMsg)



ListProviderPresets(ListProviderPresetsMsg)



ListMcps(ListMcpsMsg)

MCP management



UpsertMcp(UpsertMcpMsg)



DeleteMcp(DeleteMcpMsg)



ListAgents(ListAgentsMsg)

Agent management



GetAgent(GetAgentMsg)



CreateAgent(CreateAgentMsg)



UpdateAgent(UpdateAgentMsg)



DeleteAgent(DeleteAgentMsg)



RenameAgent(RenameAgentMsg)



InstallPlugin(InstallPluginMsg)

Plugins



UninstallPlugin(UninstallPluginMsg)



ListPlugins(ListPluginsMsg)



ListSkills(ListSkillsMsg)

Skills



ListModels(ListModelsMsg)

Models



SearchPlugins(SearchPluginsMsg)

Plugin search



GetConversationHistory(GetConversationHistoryMsg)

Conversation history



DeleteConversation(DeleteConversationMsg)

Delete conversation



StartService(StartServiceMsg)

Services



StopService(StopServiceMsg)



ServiceLogs(ServiceLogsMsg)



CreateCron(CreateCronMsg)

Cron



DeleteCron(DeleteCronMsg)



ListCrons(ListCronsMsg)



Ping(Ping)

Daemon lifecycle



GetConfig(GetConfig)



Reload(ReloadMsg)



GetStats(GetStats)



SubscribeEvents(SubscribeEvents)



SubscribeEvent(SubscribeEventMsg)

Event bus



UnsubscribeEvent(UnsubscribeEventMsg)



ListSubscriptions(ListSubscriptionsMsg)



PublishEvent(PublishEventMsg)



SteerSession(SteerSessionMsg)

Steering



Extension(Vec<u8>)

Extension point for downstream products.

Implementations

Source

impl Msg

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Msg>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.