pub struct SendMsg {
pub agent: String,
pub content: String,
pub sender: Option<String>,
pub cwd: Option<String>,
pub guest: Option<String>,
pub tool_choice: Option<String>,
}Fields
agent: Stringcontent: Stringsender: Option<String>cwd: Option<String>guest: Option<String>tool_choice: Option<String>Implementations
Sourceimpl SendMsg
impl SendMsg
Sourcepub fn sender(&self) -> &str
pub fn sender(&self) -> &str
Returns the value of sender, or the default value if sender is unset.
Sourcepub fn guest(&self) -> &str
pub fn guest(&self) -> &str
Returns the value of guest, or the default value if guest is unset.
Sourcepub fn tool_choice(&self) -> &str
pub fn tool_choice(&self) -> &str
Returns the value of tool_choice, or the default value if tool_choice is unset.