pub struct MessageBuilder { /* private fields */ }Expand description
Accumulating builder for streaming assistant messages.
Implementations
Sourceimpl MessageBuilder
impl MessageBuilder
Sourcepub fn new(role: Role) -> Self
pub fn new(role: Role) -> Self
Create a new builder for the given role (typically Role::Assistant).
Sourcepub fn accept(&mut self, chunk: &ChatCompletionChunk) -> bool
pub fn accept(&mut self, chunk: &ChatCompletionChunk) -> bool
Accept one streaming chunk.
Returns true if this chunk contributed visible text content.
Sourcepub fn peek_tool_calls(&self) -> Vec<ToolCall>
pub fn peek_tool_calls(&self) -> Vec<ToolCall>
Snapshot of tool calls accumulated so far.