pub enum Msg {
Show 28 variants
Error(ErrorMsg),
Pong(Pong),
Response(SendResponse),
Stream(StreamEvent),
ActiveConversations(ActiveConversationList),
Compact(CompactResponse),
ConversationList(ConversationList),
ProviderList(ProviderList),
ProviderPresetList(ProviderPresetList),
McpList(McpList),
AgentInfo(AgentInfo),
AgentList(AgentList),
PluginEvent(PluginEvent),
PluginList(PluginList),
SkillList(SkillList),
ModelList(ModelList),
PluginSearchList(PluginSearchList),
ConversationHistory(ConversationHistory),
ServiceLogOutput(ServiceLogOutput),
CronInfo(CronInfo),
CronList(CronList),
Config(ConfigMsg),
Stats(DaemonStats),
AgentEvent(AgentEventMsg),
SubscriptionInfo(SubscriptionInfo),
SubscriptionList(SubscriptionList),
McpInfo(McpInfo),
Extension(Vec<u8>),
}Variants
Error(ErrorMsg)
Common
Pong(Pong)
Response(SendResponse)
Execution
Stream(StreamEvent)
ActiveConversations(ActiveConversationList)
Active conversations
Compact(CompactResponse)
ConversationList(ConversationList)
ProviderList(ProviderList)
Provider
ProviderPresetList(ProviderPresetList)
McpList(McpList)
MCP
AgentInfo(AgentInfo)
Agent
AgentList(AgentList)
PluginEvent(PluginEvent)
Plugins
PluginList(PluginList)
SkillList(SkillList)
Skills
ModelList(ModelList)
Models
PluginSearchList(PluginSearchList)
Plugin search
ConversationHistory(ConversationHistory)
Conversation history
ServiceLogOutput(ServiceLogOutput)
Services
CronInfo(CronInfo)
Cron
CronList(CronList)
Config(ConfigMsg)
Daemon lifecycle
Stats(DaemonStats)
AgentEvent(AgentEventMsg)
SubscriptionInfo(SubscriptionInfo)
Event bus
SubscriptionList(SubscriptionList)
McpInfo(McpInfo)
MCP CRUD response (single-item)
Extension(Vec<u8>)
Extension point for downstream products.
Implementations
Sourceimpl Msg
impl Msg
Sourcepub fn merge(
field: &mut Option<Msg>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Msg>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.